draw_grade_density.RdFunction drawing grade density and positioning the student relative to the mean and median and showing the status areas.
draw_grade_density(
grades,
studentid,
structure,
labels = base::list(x = "Grade", y = "Proportion", avg = "Mean", med = "Median", stu =
"You")
)Tibble. List of grades of all students. Three necessary variables: student, points, grade.
Character. ID of the student.
Tibble. Variables: threshold, status, color, and comment. Comment is not necessary.
List. Names for axes and legends (for translations purposes)
A ggplot object ready for rendering.