edit_diagram_server.RdModule facilitating the quick creation of diagrams embedded in functions or documents.
edit_diagram_server(id)Character. ID of the module to connect the user interface to the appropriate server side.
Write lines of codes creating the different parts of a diagram which can then be embedded in function or document.