Function creating a basic diagram serving as a basis to be adjusted with the edit_diagram module.

initialize_diagram()

Value

A list of tibbles specifying nodes, relations, and moderations.

Author

Nicolas Mangin