Take a table and transforms it into lines of code which can be written and inserted.

write_table_code(table, name)

Arguments

table

Data.frame or tibble. Table which should be written as code.

name

Character. Name of the resulting table.

Value

A vector of character in which entries are lines to be written.

Author

Nicolas Mangin