write_table_code.RdTake a table and transforms it into lines of code which can be written and inserted.
write_table_code(table, name)Data.frame or tibble. Table which should be written as code.
Character. Name of the resulting table.
A vector of character in which entries are lines to be written.